@@ -19,8 +19,6 @@
  */
 
 #include "config.h"
-#include <libgnome/libgnome.h>
-#include <libgnomeui/libgnomeui.h>
 #include <gdk/gdkx.h>
 #include <X11/Xauth.h>
 
