@@ -18,9 +18,13 @@
 
 #include "config.h"
 
+#include <string.h>
 #include <gtk/gtk.h>
-#include <libgnome/libgnome.h>
+#include <glib/gi18n.h>
 #include <gdk/gdkkeysyms.h>
+
+#include "viciousui.h"
+
 #include "greeter.h"
 #include "greeter_item_pam.h"
 #include "greeter_item_ulist.h"
@@ -31,9 +35,6 @@
 #include "gdm.h"
 #include "gdmwm.h"
 #include "gdmcommon.h"
-#include "vicious.h"
-#include "viciousui.h"
-#include <string.h>
 
 static gboolean messages_to_give = FALSE;
 static gboolean replace_msg = TRUE;
@@ -96,6 +97,8 @@ greeter_item_pam_login (GtkEntry *entry, GreeterItemInfo *info)
   char *tmp;
   GreeterItemInfo *error_info;
 
+  greeter_ignore_buttons (TRUE);
+
   str = gtk_entry_get_text (GTK_ENTRY (entry));
   if (greeter_probably_login_prompt &&
       /* evilness */
@@ -333,9 +336,8 @@ greeter_item_pam_leftover_messages (void)
 				   GTK_DIALOG_MODAL /* flags */,
 				   GTK_MESSAGE_INFO,
 				   GTK_BUTTONS_OK,
-				   FALSE /* markup */,
 				   oldtext,
-				   /* avoid warning */ "%s", "");
+				   "");
 	  gtk_dialog_set_has_separator (GTK_DIALOG (dlg), FALSE);
 	  gtk_window_set_modal (GTK_WINDOW (dlg), TRUE);
 	  gdm_wm_center_window (GTK_WINDOW (dlg));
